.. :changelog:

History
-------

Current
+++++++

* Added stats toxenv to show coverage stats
* Corrected v0.1.0 release date in history
* Added setting the Django `EMAIL_BACKEND` setting to quickstart and usage
* Added django cache backend
* Fixed handling of quoted-printable email encoding
* Dropped testing of Django 1.8, added testing of Django 1.11 and Python 3.6

0.1.0 (2016-12-23)
++++++++++++++++++

* First release on PyPI.
